FooterToolsWidget class

A widget for displaying footer tools.

This widget is a part of the UI where the user can interact with footer tools. It is a stateless widget that takes several parameters to control its behavior and appearance. It uses an ElevatedButton to display a done button, and the user can interact with it by tapping on it.

Inheritance

Constructors

FooterToolsWidget({Key? key, required AsyncCallback onDone, Widget? doneButtonChild, bool isLoading = false, Widget doneButtonBuilder(StoryMakerTheme theme, AsyncCallback onDone, bool isLoading)?})
Creates an instance of the widget.
const

Properties

doneButtonBuilder → Widget Function(StoryMakerTheme theme, AsyncCallback onDone, bool isLoading)?
Custom widget builder for the done button. If provided, this will be used instead of the default button.
final
doneButtonChild → Widget?
The child widget of the done button.
final
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
Indicates whether the widget is in loading state.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDone → AsyncCallback
A callback function that is called when the done button is pressed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited