RemoveWidget class

A widget for removing an item.

This widget is a part of the UI where the user can remove an item. It is a stateless widget that takes several parameters to control its behavior and appearance. It uses a Visibility widget to display the remove button, and the user can interact with it by tapping on it.

Inheritance

Constructors

RemoveWidget({Key? key, required bool isTextInput, required EditableItem? activeItem, required bool isDeletePosition, required Duration animationsDuration})
Creates an instance of the widget.
const

Properties

animationsDuration → Duration
The duration of animations within the widget.
final
hashCode → int
The hash code for this object.
no setterinherited
isDeletePosition → bool
Indicates whether the widget is in delete position.
final
isTextInput → bool
Indicates whether the widget is in text input mode.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited