ViewportFractions class

UI constants used throughout the story maker.

This file contains all magic numbers and UI-related constants to make the codebase more maintainable and easier to configure. Viewport fractions for PageControllers

Constructors

ViewportFractions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fontFamily → const double
Viewport fraction for font family PageController
gradients → const double
Viewport fraction for gradients PageController
textColors → const double
Viewport fraction for text colors PageController