BuildContextExtensions extension

Extension on BuildContext to add additional properties and methods.

on

Properties

bottomPadding → double

Available on BuildContext, provided by the BuildContextExtensions extension

Get the bottom padding of the screen from the current BuildContext.
no setter
height → double

Available on BuildContext, provided by the BuildContextExtensions extension

Get the height of the screen from the current BuildContext.
no setter
media → MediaQueryData

Available on BuildContext, provided by the BuildContextExtensions extension

Get the MediaQueryData from the current BuildContext.
no setter
theme → ThemeData

Available on BuildContext, provided by the BuildContextExtensions extension

Get the ThemeData from the current BuildContext.
no setter
topPadding → double

Available on BuildContext, provided by the BuildContextExtensions extension

Get the top padding of the screen from the current BuildContext.
no setter
width → double

Available on BuildContext, provided by the BuildContextExtensions extension

Get the width of the screen from the current BuildContext.
no setter